@@ -178,6 +178,8 @@ impl Opcode {
 	pub const BALANCE: Opcode = Opcode(0x31);
 	/// `SELFBALANCE`
 	pub const SELFBALANCE: Opcode = Opcode(0x47);
+	/// `BASEFEE`
+	pub const BASEFEE: Opcode = Opcode(0x48);
 	/// `ORIGIN`
 	pub const ORIGIN: Opcode = Opcode(0x32);
 	/// `CALLER`
